function [p,lambda,l0,la,df,P,P1,P2]=LRtest(Y1,Y2)
%likelihood ratio test for transition counts in a discrete-time Markov model: aggregate Y1 and Y2?
%SYNTAX
%[p,lambda,l0,la,df,P,P1,P2]=LRtest(Y1,Y2)
%INPUTS
%Y1 and Y2 are two discrete-time transition count matrices: elements
%i,j are transition counts from j to i
%OUTPUTS
%p is a p-value from a likelihood ratio test of the null hypothesis that Y1
%and Y2 are generated by the same discrete-time Markov chains, against the
%alternative that they are generated by different discrete-time Markov
%chains
%lambda is the likelihood ratio statistic
%l0 is the log likelihood for the null hypothesis
%la is thelog likelihood for the alternative hypothesis
%df is the degrees of freedom
%P is ML estimate of transition probabilities for the aggregated model
%P1 and P2 are ML estimates of transition probabilities for each count
%matrix separately
%USES
%discretetime_loglike.m

Y=Y1+Y2;
[l0,P]=discretetime_loglike(Y);%aggregated

[l1,P1]=discretetime_loglike(Y1);
[l2,P2]=discretetime_loglike(Y2);
la=l1+l2;

lambda=2*(la-l0);
s=size(Y,1);
df=s*(s-1);
p=1-chi2cdf(lambda,df);


