function [C,Nstart,Avcoral,Avalgae]=counttransitions(X,Y,statedef,startyear)
%transition counts from observations at one-year intervals
%SYNTAX
%[C,Nstart,Avcoral,Avalgae]=counttransitions(X,Y,statedef,startyear)
%INPUTS
%X is a matrix where each row is an observation, with columns:
%reefid year coral algae others (as proportions)
%for observations that have another observation one year later on the same
%reef
%Y is a matrix in the same form, but such that row i of Y corresponds to
%the state of the reef in row i of X one year later
%statedef has one row per state, and cols min coral (c1), max coral (c2), min algae (a1),
%max algae (a2) for that state (as proportions)
%startyear is the year that we want to use to count states towards initial
%conditions for model
%OUTPUTS
%C is a matrix of transition counts, where column is source state and row
%is destination state
%Nstart is a column vector of state counts in year startyear
%Avcoral and Avalgae are column vectors of mean coral and algal cover in
%each state (averaged over all observations, whether source or destination,
%but counting each observation only once)
%USES
%classifystate.m

n=size(X,1);
s=size(statedef,1);
C=zeros(s);
Nstart=zeros(s,1);
Avcoral=Nstart;
Avalgae=Nstart;
nc=Nstart;
na=Nstart;
ri=-1;
oy=-1;
for k=1:n
    x=X(k,3:5);
    y=Y(k,3:5);
    i=classifystate(y,statedef);%destination state
    j=classifystate(x,statedef);%source state
    C(i,j)=C(i,j)+1;
    Avcoral(i)=Avcoral(i)+y(1);%contribution to mean coral cover in this state
    Avalgae(i)=Avalgae(i)+y(2);%contribution to mean algal cover in this state
    nc(i)=nc(i)+1;
    na(i)=na(i)+1;
    if X(k,1)~=ri || X(k,2)~=oy+1%we've either changed reef or had a break in observations: count the X as well towards average cover
        Avcoral(j)=Avcoral(j)+x(1);%contribution to mean coral cover in this state
        Avalgae(j)=Avalgae(j)+x(2);%contribution to mean algal cover in this state
        nc(j)=nc(j)+1;
        na(j)=na(j)+1;
    end
    ri=X(k,1);
    oy=X(k,2);
    if Y(k,2)==startyear%this observation is from the year we're interested in
        Nstart(i)=Nstart(i)+1;
    end
end
Avcoral=Avcoral./nc;
Avalgae=Avalgae./na;