function [l,P]=discretetime_loglike(Y,Pin)
%log likelihood for a discrete-time Markov model
%SYNTAX
%[l,P]=discretetime_loglike(Y,Pin)
%INPUTS
%Y is a matrix of transition counts: element i,j is transition from j to i
%Pin (optional) is a transition probability matrix. If supplied, compute
%log likelihood for this. If not, compute maximum log likelihood.
%OUTPUTS
%l is the log likelihood
%P is the transition probability matrix (ML estimate)

if nargin<2
    Pin=[];
end

s=size(Y,1);
Ysum=sum(Y);
Ysum=Ysum(ones(s,1),:);
P=Y./Ysum;
ind=logical(Y>0);%0*log(0)=0

if isempty(Pin)
    l=sum(Y(ind).*log(P(ind)));%maximum log likelihood
else
    l=sum(Y(ind).*log(Pin(ind)));%log likelihood
end