%example Matlab script for Lowe et al. (unpublished). Empirical models of
%transitions between coral reef states: effects of regions, marine
%protected areas, and environmental change scenarios
%Uses simulated data
%
%Tested with
%MATLAB Version 7.9.0.529 (R2009b)
%Operating System: Linux 2.6.26-2-686 #1 SMP Thu Jan 27 00:28:05 UTC 2011 i686
%Statistics Toolbox                                    Version 7.2        (R2009b)
%
%Matthew Spencer, School of Environmental Sciences, University of Liverpool
%2 October 2010


clear;
skip=zeros(3,1);%zeros for analyses we want to do this time. Set elements we don't want to run to 1
%1: basic analysis
%2: likelihood ratio test: first vs second time periods
%3. environmental change scenario

if ~skip(1)%basic analysis
    %load the simulated data
    testdata=dlmread('simulated_data.txt',',',1,0);
    reefid=testdata(:,1);
    year=testdata(:,2);
    data=testdata(:,3:5);
    [X,Y]=constructXY(reefid,data,year);    

    load statedef %state definitions
    
    stateplot(X,Y);%plot of trajectories and states
    pause()
    
    startyear=0;%year in which to count initial state distribution
    [C,Nstart,Avcoral,Avalgae]=counttransitions(X,Y,statedef,startyear);%get transition counts, initial state counts, average coral and algae in state
    tmax=10;
    reps=10000;
    [Stationary,stateprobstime,covertime,stationarycover,Damping]=Bayes_sample_percent_cover2(C,reps,tmax,Avcoral*100,Avalgae*100,Nstart,[],[],[0 100],[0 40]);%Bayesian analysis of Markov chain
    
    plotPposterior(C,statenames);%posterior distributions of transition probabilities
    pause()
end

if ~skip(2)%LR test: first and second half the same?
    %load the data
    testdata=dlmread('simulated_data.txt',',',1,0);
    reefid=testdata(:,1);
    year=testdata(:,2);
    data=testdata(:,3:5);
    [X,Y]=constructXY(reefid,data,year);    

    load statedef %state definitions
    cutyear=2;
    X1=X(logical(X(:,2)<=cutyear),:);
    Y1=Y(logical(X(:,2)<=cutyear),:);
    X2=X(logical(X(:,2)>cutyear),:);
    Y2=Y(logical(X(:,2)>cutyear),:);
    C1=counttransitions(X1,Y1,statedef,startyear);
    C2=counttransitions(X2,Y2,statedef,startyear);
    [p,lambda,l0,la,df,P,P1,P2]=LRtest(C1,C2);
    disp(['first vs second half: lambda=',num2str(lambda),', df=',num2str(df),', p=',num2str(p)]);
end

if ~skip(3)%one change scenario with a range of predictor values: takes a few minutes
    %load the data
    testdata=dlmread('simulated_data.txt',',',1,0);
    reefid=testdata(:,1);
    year=testdata(:,2);
    data=testdata(:,3:5);
    [X,Y]=constructXY(reefid,data,year);    
    
    [C,Nstart,Avcoral,Avalgae]=counttransitions(X,Y,statedef,startyear);%get transition counts, initial state counts, average coral and algae in state
    tmax=10;
    reps=10000;
    changepattern1=[0 1 1;-1 0 1;-1 -1 0];%increase transitions that increase coral and/or decrease algae, and vice versa
    beta1=mapchangepattern(changepattern1,Avcoral,Avalgae);%how does this change pattern affect transition probs?
    x=-2:0.2:2;
    nx=length(x);
    sci=zeros(2,nx);
    rci=zeros(1,nx);
    scarray=zeros(2,reps,nx);
    for i=1:length(x)
        [Stationaryi,stateprobstimei,covertimei,stationarycoveri,Dampingi,relchangei]=Bayes_sample_percent_cover2(C,reps,tmax,Avcoral*100,Avalgae*100,Nstart,beta1,x(i),[0 70],[0 40],0);%Bayesian analysis of Markov chain
        sci(:,i)=mean(stationarycoveri,2);
        rci(i)=mean(relchangei);
        scarray(:,:,i)=stationarycoveri;
    end
    disp('coral posterior mean and 95% credible interval at extremes of x');
    coralpsummary=[mean(scarray(1,:,1)) quantile(scarray(1,:,1),0.05) quantile(scarray(1,:,1),0.95);mean(scarray(1,:,length(x))) quantile(scarray(1,:,length(x)),0.05) quantile(scarray(1,:,length(x)),0.95);]
    disp('algal posterior mean and 95% credible interval at extremes of x');
    algalpsummary=[mean(scarray(2,:,1)) quantile(scarray(2,:,1),0.05) quantile(scarray(2,:,1),0.95);mean(scarray(2,:,length(x))) quantile(scarray(2,:,length(x)),0.05) quantile(scarray(2,:,length(x)),0.95);]
    figure(1);
    clf;
    subplot(2,1,1);
    scenario_summary([0.95 0.5],'\itx','Equilibrium coral cover',scarray,x,1,[0 70],'A: coral');
    subplot(2,1,2);
    scenario_summary([0.95 0.5],'\itx','Equilibrium algal cover',scarray,x,2,[0 70],'B: macroalgae');
end
