function beta=mapchangepattern(changepattern,Avcoral,Avalgae)
%construct a change scenario for a transition probability matrix, given a
%scenario for the changes in transitions involving each possible
%combination of increases and decreases in coral and algal cover, and the
%observed mean coral and algal cover in each state
%SYNTAX
%beta=mapchangepattern(changepattern,Avcoral,Avalgae)
%INPUTS
%changepattern is a -1/0/+1 matrix of change directions in algal (A) and
%coral (C) cover, arranged as follows:
%+A+C 0A+C -A+C
%+A0C 0A0C -A0C
%+A-C 0A-C -A-C
%Avcoral is a vector of mean coral cover in each state
%Avalgae is a vector of mean algal cover in each state
%OUTPUTS
%beta is a -1/0/+1 matrix of change directions in the transition
%probability matrix (columns are source states, rows are destination states

s=length(Avcoral);
beta=zeros(s);
for i=1:s
    for j=1:s
        if Avcoral(i)>Avcoral(j)
            if Avalgae(i)>Avalgae(j)
               beta(i,j)=changepattern(1,1); 
            elseif Avalgae(i)==Avalgae(j)
               beta(i,j)=changepattern(1,2); 
            else
               beta(i,j)=changepattern(1,3); 
            end
        elseif Avcoral(i)==Avcoral(j)
            if Avalgae(i)>Avalgae(j)
               beta(i,j)=changepattern(2,1); 
            elseif Avalgae(i)==Avalgae(j)
               beta(i,j)=changepattern(2,2); 
            else
               beta(i,j)=changepattern(2,3); 
            end
        else
            if Avalgae(i)>Avalgae(j)
               beta(i,j)=changepattern(3,1); 
            elseif Avalgae(i)==Avalgae(j)
               beta(i,j)=changepattern(3,2); 
            else
               beta(i,j)=changepattern(3,3); 
            end
        end
    end
end