function Pchange=multinomial_logit(P,beta,x)
%use multinomial logit model to make specified changes to a transition
%probability matrix
%SYNTAX
%Pchange=multinomial_logit(P,beta,x)
%INPUTS
%P is a transition probability matrix (element i,j is probability of
%transitions from j to i)
%beta is a matrix (the same size as P) of directions of change in each
%transition probability (typically contains only -1, 0 and 1 values). The
%diagonal should be zeros.
%x is the size of change in a dummy explanatory variable (which we treat as
%if it's centred at the value that applies to the input transition matrix
%P)
%OUTPUTS
%P change is a transition probability matrix derived from P by applying a
%multinomial logit model. The matrix beta is used as the coefficients in a
%multinomial logit model for the transition probabilities in each column,
%compared to the diagonal element (used as a reference category).

n=size(P,1);

%calculate the alphas assuming we've centred the explanatory variable at
%its current value
ref=diag(P)';
ref=ref(ones(n,1),:);
alpha=log(P./ref);
phi=exp(alpha+beta*x);%exp logit relative to reference category
sphi=phi;
sphi(logical(eye(n)))=0;%exclude reference category
D=1+sum(sphi);
D=D(ones(n,1),:);
Pchange=phi./D;

