function plotPposterior(Y,statenames)
%plot posterior marginal distribution of each transition probability under
%Dirichlet-multinomial model with uniform Dirichlet prior
%SYNTAX
%plotPposterior(Y,statenames)
%INPUTS
%Y is a matrix whose elements i,j are the numbers of observations of
%transitions from state j to state i
%statenames (optional) is a cell array of state names
%OUTPUTS
%A set of panels plotting the posterior marginal density for each
%transition probability p_ij. The uniform priors are shown as dashed lines.

if nargin<2
   statenames=cellstr(num2str((1:size(Y,1))')); 
end

s=size(Y,1);
alpha=Y+1;%parameters for Dirichlet posterior with uniform Dirichlet prior
alpha0=sum(alpha);
x=0:0.01:1;
figure(1);
clf;
yl=[0 0];
for i=1:s
    for j=1:s
        subplot(s,s,j+s*(i-1));
        y=betapdf(x,alpha(i,j),alpha0(j)-alpha(i,j));%marginal distribution is beta(alpha_j,alpha_0-alpha_j);
        h=plot(x,y,'k-',[0 1],[1 1],'k--');
        set(gca,'xlim',[0,1]);
        if i<s
            set(gca,'xticklabel',[]);
        else
            xlabel({'Transition','probability'},'fontname','Arial');
        end
        if j==1
            ylabel('Density','fontname','Arial');
        end
        ytemp=get(gca,'ylim');
        if ytemp(2)>yl(2)
            yl(2)=ytemp(2);
        end
    end
end
        

for i=1:s
    for j=1:s
        subplot(s,s,j+s*(i-1));
%        set(gca,'ylim',yl);%set all y scales to a common value: probably not a good idea
        yt=get(gca,'ylim');
        xt=get(gca,'xlim');
        addval=j+s*(i-1)-1;%construct panel label
        if addval>25
            mylabel=char(double('A')+floor(addval/26)-1);
            addval=rem(addval,26);
        else
            mylabel=[];
        end
        %mylabel=[mylabel,char(double('A')+addval),': p_{',num2str(i),num2str(j),'}'];
        mylabel=[mylabel,char(double('A')+addval),': p_{',statenames{i},statenames{j},'}'];
        text(xt(2)-0.55*range(xt),yt(2)-0.2*range(yt),mylabel,'fontsize',8,'fontname','Arial');
        set(gca,'xlim',xt,'ylim',yt,'fontname','Arial');
    end
end