function stateplot(X,Y)
%plot discrete state map for coral/algae data
%SYNTAX
%stateplot(X,Y)
%INPUTS
%X is a matrix where each row is an observation, with columns:
%reefid year coral algae others (as proportions)
%for observations that have another observation one year later on the same
%reef
%Y is a matrix in the same form, but such that row i of Y corresponds to
%the state of the reef in row i of X one year later
%OUTPUTS
%A scatter plot of states (blue circles), what happened the next year (red
%dots), linked by grey lines
%with state boundaries marked

figure(1);
clf;
axis equal;
set(gca,'xlim',[0 100],'ylim',[0 100]);
set(gca,'xtick',0:25:100,'ytick',0:25:100);
hold on;
for i=1:length(X)%plot the observations
    plot(X(i,3)*100,X(i,4)*100,'bo');
    plot(Y(i,3)*100,Y(i,4)*100,'r.');
    plot([X(i,3);Y(i,3)]*100,[X(i,4);Y(i,4)]*100,'-','color',[0.7 0.7 0.7]);
end;
%state boundaries
plot([0;100],[100;0],'k-');
plot([0;50],[50;50],'k-')
plot([0;50],[25;25],'k-')
plot([50;50],[0;50],'k-')
plot([25;25],[0;50],'k-')

%axis labels
xlabel('coral','fontname','Arial','fontsize',18);
ylabel('macroalgae','fontname','Arial','fontsize',18);
set(gca,'fontname','Arial');

%state labels
text(5,20,'A');
text(5,45,'B');
text(5,80,'C');
text(30,20,'D');
text(30,45,'E');
text(55,20,'F');
